SendSmsResponse_SmsResponse class
- Inheritance
-
- Object
- ProtobufEnum
- SendSmsResponse_SmsResponse
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
This enum's name, as specified in the .proto file.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
This enum's integer value, as specified in the .proto file.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns this enum's
nameor thevalueif names are not represented.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
valueOf(
int value) → SendSmsResponse_SmsResponse?
Constants
- SMS_RESPONSE_INVALID_PHONE_NUMBER → const SendSmsResponse_SmsResponse
- SMS_RESPONSE_MISSING_MESSAGE → const SendSmsResponse_SmsResponse
- SMS_RESPONSE_SENDER_SERVICE_ACCOUNT_FAILURE → const SendSmsResponse_SmsResponse
- SMS_RESPONSE_SENDER_SERVICE_GENERIC_FAILURE → const SendSmsResponse_SmsResponse
- SMS_RESPONSE_SENT_SUCCESSFULLY → const SendSmsResponse_SmsResponse
- SMS_RESPONSE_UNSPECIFIED → const SendSmsResponse_SmsResponse
-
values
→ const List<
SendSmsResponse_SmsResponse>