DataExportServiceClient class

Annotations
  • @GrpcServiceName.new('integrations.v1.DataExportService')

Constructors

DataExportServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
getLaborEmployeeJobs(GetLaborEmployeeJobsRequest request, {CallOptions? options}) → ResponseFuture<GetLaborEmployeeJobsResponse>
getLaborEmployees(GetLaborEmployeesRequest request, {CallOptions? options}) → ResponseFuture<GetLaborEmployeesResponse>
getLaborJobs(GetLaborJobsRequest request, {CallOptions? options}) → ResponseFuture<GetLaborJobsResponse>
getLaborTimeCards(GetLaborTimeCardsRequest request, {CallOptions? options}) → ResponseFuture<GetLaborTimeCardsResponse>
getSales(GetSalesRequest request, {CallOptions? options}) → ResponseFuture<GetSalesResponse>
getSalesDetails(GetSalesDetailsRequest request, {CallOptions? options}) → ResponseFuture<GetSalesDetailsResponse>
getSalesPayments(GetSalesPaymentsRequest request, {CallOptions? options}) → ResponseFuture<GetSalesPaymentsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited