IpadShift class
- Inheritance
-
- Object
- GeneratedMessage
- IpadShift
Constructors
-
IpadShift({String? shiftId, String? createdDate, String? shiftStartTime, String? shiftEndTime, bool? creditTipped, bool? cashTipped, String? userId, String? username, String? roleName, String? rolesAndPermissionsId, double? cashTips, double? creditCardTips, String? clockOutType, String? date, double? tipTotal, double? totalHoursWorked, bool? isActive, IpadShiftUser? user, String? histories})
-
factory
-
IpadShift.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
-
IpadShift.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
-
factory
Methods
-
addExtension(Extension extension, Object? value)
→ void
-
Adds an extension field value to a repeated field.
inherited
-
check()
→ void
-
inherited
-
clear()
→ void
-
Clears all data that was set in this message.
inherited
-
clearCashTipped()
→ void
-
-
clearCashTips()
→ void
-
-
clearClockOutType()
→ void
-
-
clearCreatedDate()
→ void
-
-
clearCreditCardTips()
→ void
-
-
clearCreditTipped()
→ void
-
-
clearDate()
→ void
-
-
clearExtension(Extension extension)
→ void
-
Clears an extension field and also removes the extension.
inherited
-
clearField(int tagNumber)
→ void
-
Clears the contents of a given field.
inherited
-
clearHistories()
→ void
-
-
clearIsActive()
→ void
-
-
clearRoleName()
→ void
-
-
clearRolesAndPermissionsId()
→ void
-
-
clearShiftEndTime()
→ void
-
-
clearShiftId()
→ void
-
-
clearShiftStartTime()
→ void
-
-
clearTipTotal()
→ void
-
-
clearTotalHoursWorked()
→ void
-
-
clearUser()
→ void
-
-
clearUserId()
→ void
-
-
clearUsername()
→ void
-
-
clone()
→ IpadShift
-
Creates a deep copy of the fields in this message.
(The generated code uses mergeFromMessage.)
override
-
copyWith(void updates(IpadShift))
→ IpadShift
-
Apply
updates to a copy of this message.
override
-
createEmptyInstance()
→ IpadShift
-
Creates an empty instance of the same message type as this.
override
-
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi)
→ Map<K, V>
-
Creates a Map representing a map field.
inherited
-
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi)
→ List<T>
-
Creates List implementing a mutable repeated field.
inherited
-
ensureUser()
→ IpadShiftUser
-
-
extensionsAreInitialized()
→ bool
-
inherited
-
freeze()
→ GeneratedMessage
-
Make this message read-only.
inherited
-
getDefaultForField(int tagNumber)
→ dynamic
-
Returns the default value for the given field.
inherited
-
getExtension(Extension extension)
→ dynamic
-
Returns the value of
extension.
inherited
-
getField(int tagNumber)
→ dynamic
-
Returns the value of the field associated with
tagNumber, or the
default value if it is not set.
inherited
-
getFieldOrNull(int tagNumber)
→ dynamic
-
Returns the value of a field, ignoring any defaults.
inherited
-
getTagNumber(String fieldName)
→ int?
-
inherited
-
hasCashTipped()
→ bool
-
-
hasCashTips()
→ bool
-
-
hasClockOutType()
→ bool
-
-
hasCreatedDate()
→ bool
-
-
hasCreditCardTips()
→ bool
-
-
hasCreditTipped()
→ bool
-
-
hasDate()
→ bool
-
-
hasExtension(Extension extension)
→ bool
-
Returns
true if a value of extension is present.
inherited
-
hasField(int tagNumber)
→ bool
-
Whether this message has a field associated with
tagNumber.
inherited
-
hasHistories()
→ bool
-
-
hasIsActive()
→ bool
-
-
hasRequiredFields()
→ bool
-
Whether the message has required fields.
inherited
-
hasRoleName()
→ bool
-
-
hasRolesAndPermissionsId()
→ bool
-
-
hasShiftEndTime()
→ bool
-
-
hasShiftId()
→ bool
-
-
hasShiftStartTime()
→ bool
-
-
hasTipTotal()
→ bool
-
-
hasTotalHoursWorked()
→ bool
-
-
hasUser()
→ bool
-
-
hasUserId()
→ bool
-
-
hasUsername()
→ bool
-
-
isInitialized()
→ bool
-
Whether all required fields in the message and embedded messages are set.
inherited
-
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges serialized protocol buffer data into this message.
inherited
-
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
inherited
-
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges field values from
data, a JSON object, encoded as described by
GeneratedMessage.writeToJson.
inherited
-
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY])
→ void
-
Merges field values from a JSON object represented as a Dart map.
inherited
-
mergeFromMessage(GeneratedMessage other)
→ void
-
Merges the contents of the
other into this message.
inherited
-
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false})
→ void
-
Merges field values from
json, a JSON object using proto3 encoding.
inherited
-
mergeUnknownFields(UnknownFieldSet unknownFieldSet)
→ void
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
setExtension(Extension extension, Object value)
→ void
-
Sets the value of a non-repeated extension field to
value.
inherited
-
setField(int tagNumber, Object value)
→ void
-
Sets the value of a field by its
tagNumber.
inherited
-
toBuilder()
→ GeneratedMessage
-
Creates a writable, shallow copy of this message.
inherited
-
toDebugString()
→ String
-
Returns a String representation of this message.
inherited
-
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()})
→ Object?
-
Returns an Object representing Proto3 JSON serialization of
this.
inherited
-
toString()
→ String
-
Returns a String representation of this message.
inherited
-
writeToBuffer()
→ Uint8List
-
inherited
-
writeToCodedBufferWriter(CodedBufferWriter output)
→ void
-
inherited
-
writeToJson()
→ String
-
Returns a JSON string that encodes this message.
inherited
-
writeToJsonMap()
→ Map<String, dynamic>
-
Returns the JSON encoding of this message as a Dart Map.
inherited