RolesServiceBase class abstract

Annotations
  • @GrpcServiceName.new('labor.v1.RolesService')

Constructors

RolesServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
createRole(ServiceCall call, CreateRoleRequest request) Future<CreateRoleResponse>
createRole_Pre(ServiceCall call, Future<CreateRoleRequest> request) Future<CreateRoleResponse>
deleteRole(ServiceCall call, DeleteRoleRequest request) Future<DeleteRoleResponse>
deleteRole_Pre(ServiceCall call, Future<DeleteRoleRequest> request) Future<DeleteRoleResponse>
getAllRoles(ServiceCall call, GetAllRolesRequest request) Future<GetAllRolesResponse>
getAllRoles_Pre(ServiceCall call, Future<GetAllRolesRequest> request) Future<GetAllRolesResponse>
getRole(ServiceCall call, GetRoleRequest request) Future<GetRoleResponse>
getRole_Pre(ServiceCall call, Future<GetRoleRequest> request) Future<GetRoleResponse>
getRoleAvatar(ServiceCall call, GetRoleAvatarRequest request) Future<GetRoleAvatarResponse>
getRoleAvatar_Pre(ServiceCall call, Future<GetRoleAvatarRequest> request) Future<GetRoleAvatarResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAvatar(ServiceCall call, UpdateAvatarRequest request) Future<UpdateAvatarResponse>
updateAvatar_Pre(ServiceCall call, Future<UpdateAvatarRequest> request) Future<UpdateAvatarResponse>
updateRole(ServiceCall call, UpdateRoleRequest request) Future<UpdateRoleResponse>
updateRole_Pre(ServiceCall call, Future<UpdateRoleRequest> request) Future<UpdateRoleResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited