RolesServiceClient class

Annotations
  • @GrpcServiceName.new('labor.v1.RolesService')

Constructors

RolesServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
createRole(CreateRoleRequest request, {CallOptions? options}) → ResponseFuture<CreateRoleResponse>
deleteRole(DeleteRoleRequest request, {CallOptions? options}) → ResponseFuture<DeleteRoleResponse>
getAllRoles(GetAllRolesRequest request, {CallOptions? options}) → ResponseFuture<GetAllRolesResponse>
getRole(GetRoleRequest request, {CallOptions? options}) → ResponseFuture<GetRoleResponse>
getRoleAvatar(GetRoleAvatarRequest request, {CallOptions? options}) → ResponseFuture<GetRoleAvatarResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateAvatar(UpdateAvatarRequest request, {CallOptions? options}) → ResponseFuture<UpdateAvatarResponse>
updateRole(UpdateRoleRequest request, {CallOptions? options}) → ResponseFuture<UpdateRoleResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited