TeamsServiceBase class abstract

Annotations
  • @GrpcServiceName.new('labor.v1.TeamsService')

Constructors

TeamsServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
activateTeam(ServiceCall call, ActivateTeamRequest request) Future<ActivateTeamResponse>
activateTeam_Pre(ServiceCall call, Future<ActivateTeamRequest> request) Future<ActivateTeamResponse>
addTeam(ServiceCall call, AddTeamRequest request) Future<AddTeamResponse>
addTeam_Pre(ServiceCall call, Future<AddTeamRequest> request) Future<AddTeamResponse>
addTeamToRole(ServiceCall call, AddTeamToRoleRequest request) Future<AddTeamToRoleResponse>
addTeamToRole_Pre(ServiceCall call, Future<AddTeamToRoleRequest> request) Future<AddTeamToRoleResponse>
deactivateTeam(ServiceCall call, DeactivateTeamRequest request) Future<DeactivateTeamResponse>
deactivateTeam_Pre(ServiceCall call, Future<DeactivateTeamRequest> request) Future<DeactivateTeamResponse>
deleteTeam(ServiceCall call, DeleteTeamRequest request) Future<DeleteTeamResponse>
deleteTeam_Pre(ServiceCall call, Future<DeleteTeamRequest> request) Future<DeleteTeamResponse>
editTeam(ServiceCall call, EditTeamRequest request) Future<EditTeamResponse>
editTeam_Pre(ServiceCall call, Future<EditTeamRequest> request) Future<EditTeamResponse>
getRolesForTeam(ServiceCall call, GetRolesForTeamRequest request) Future<GetRolesForTeamResponse>
getRolesForTeam_Pre(ServiceCall call, Future<GetRolesForTeamRequest> request) Future<GetRolesForTeamResponse>
getRolesOnTeam(ServiceCall call, GetRolesOnTeamRequest request) Future<GetRolesOnTeamResponse>
getRolesOnTeam_Pre(ServiceCall call, Future<GetRolesOnTeamRequest> request) Future<GetRolesOnTeamResponse>
getTeam(ServiceCall call, GetTeamRequest request) Future<GetTeamResponse>
getTeam_Pre(ServiceCall call, Future<GetTeamRequest> request) Future<GetTeamResponse>
getTeams(ServiceCall call, GetTeamsRequest request) Future<GetTeamsResponse>
getTeams_Pre(ServiceCall call, Future<GetTeamsRequest> request) Future<GetTeamsResponse>
getTeamsForActiveShift(ServiceCall call, GetTeamsForActiveShiftRequest request) Future<GetTeamsForActiveShiftResponse>
getTeamsForActiveShift_Pre(ServiceCall call, Future<GetTeamsForActiveShiftRequest> request) Future<GetTeamsForActiveShiftResponse>
getTeamsForRole(ServiceCall call, GetTeamsForRoleRequest request) Future<GetTeamsForRoleResponse>
getTeamsForRole_Pre(ServiceCall call, Future<GetTeamsForRoleRequest> request) Future<GetTeamsForRoleResponse>
getTeamsOnRole(ServiceCall call, GetTeamsOnRoleRequest request) Future<GetTeamsOnRoleResponse>
getTeamsOnRole_Pre(ServiceCall call, Future<GetTeamsOnRoleRequest> request) Future<GetTeamsOnRoleResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeTeamFromRole(ServiceCall call, RemoveTeamFromRoleRequest request) Future<RemoveTeamFromRoleResponse>
removeTeamFromRole_Pre(ServiceCall call, Future<RemoveTeamFromRoleRequest> request) Future<RemoveTeamFromRoleResponse>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited