OrderedItem class

Inheritance
  • Object
  • GeneratedMessage
  • OrderedItem

Constructors

OrderedItem({String? id, int? seat, int? course, bool? isSent, bool? isVoid, String? voidName, bool? isFired, String? checkId, Iterable<ItemDiscountInstance>? discounts, Item? menuItem, Iterable<ModifierInstance>? modifiers, PromotionInstance? promotion, int? numOfChecks, double? discountValue, String? itemCreatedDate, double? itemValueResponsibility, RestaurantEmployeeName? restaurantEmployee})
factory
OrderedItem.fromBuffer(List<int> i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory
OrderedItem.fromJson(String i, [ExtensionRegistry r = $pb.ExtensionRegistry.EMPTY])
factory

Properties

checkId String
getter/setter pair
course int
getter/setter pair
discounts List<ItemDiscountInstance>
no setter
discountValue double
getter/setter pair
eventPlugin → EventPlugin?
Subclasses can override this getter to be notified of changes to protobuf fields.
no setterinherited
hashCode int
Calculates a hash code based on the contents of the protobuf.
no setterinherited
id String
getter/setter pair
info_ → BuilderInfo
no setteroverride
isFired bool
getter/setter pair
isFrozen bool
Returns true if this message is marked read-only. Otherwise false.
no setterinherited
isSent bool
getter/setter pair
isVoid bool
getter/setter pair
itemCreatedDate String
getter/setter pair
itemValueResponsibility double
getter/setter pair
getter/setter pair
modifiers List<ModifierInstance>
no setter
numOfChecks int
getter/setter pair
promotion PromotionInstance
getter/setter pair
restaurantEmployee RestaurantEmployeeName
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seat int
getter/setter pair
unknownFields → UnknownFieldSet
no setterinherited
voidName String
getter/setter pair

Methods

addExtension(Extension extension, Object? value) → void
Adds an extension field value to a repeated field.
inherited
check() → void
inherited
clear() → void
Clears all data that was set in this message.
inherited
clearCheckId() → void
clearCourse() → void
clearDiscountValue() → void
clearExtension(Extension extension) → void
Clears an extension field and also removes the extension.
inherited
clearField(int tagNumber) → void
Clears the contents of a given field.
inherited
clearId() → void
clearIsFired() → void
clearIsSent() → void
clearIsVoid() → void
clearItemCreatedDate() → void
clearItemValueResponsibility() → void
clearMenuItem() → void
clearNumOfChecks() → void
clearPromotion() → void
clearRestaurantEmployee() → void
clearSeat() → void
clearVoidName() → void
clone() OrderedItem
Creates a deep copy of the fields in this message. (The generated code uses mergeFromMessage.)
override
copyWith(void updates(OrderedItem)) OrderedItem
Apply updates to a copy of this message.
override
createEmptyInstance() OrderedItem
Creates an empty instance of the same message type as this.
override
createMapField<K, V>(int tagNumber, MapFieldInfo<K, V> fi) Map<K, V>
Creates a Map representing a map field.
inherited
createRepeatedField<T>(int tagNumber, FieldInfo<T> fi) List<T>
Creates List implementing a mutable repeated field.
inherited
ensureMenuItem() Item
ensurePromotion() PromotionInstance
ensureRestaurantEmployee() RestaurantEmployeeName
extensionsAreInitialized() bool
inherited
freeze() → GeneratedMessage
Make this message read-only.
inherited
getDefaultForField(int tagNumber) → dynamic
Returns the default value for the given field.
inherited
getExtension(Extension extension) → dynamic
Returns the value of extension.
inherited
getField(int tagNumber) → dynamic
Returns the value of the field associated with tagNumber, or the default value if it is not set.
inherited
getFieldOrNull(int tagNumber) → dynamic
Returns the value of a field, ignoring any defaults.
inherited
getTagNumber(String fieldName) int?
inherited
hasCheckId() bool
hasCourse() bool
hasDiscountValue() bool
hasExtension(Extension extension) bool
Returns true if a value of extension is present.
inherited
hasField(int tagNumber) bool
Whether this message has a field associated with tagNumber.
inherited
hasId() bool
hasIsFired() bool
hasIsSent() bool
hasIsVoid() bool
hasItemCreatedDate() bool
hasItemValueResponsibility() bool
hasMenuItem() bool
hasNumOfChecks() bool
hasPromotion() bool
hasRequiredFields() bool
Whether the message has required fields.
inherited
hasRestaurantEmployee() bool
hasSeat() bool
hasVoidName() bool
isInitialized() bool
Whether all required fields in the message and embedded messages are set.
inherited
mergeFromBuffer(List<int> input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges serialized protocol buffer data into this message.
inherited
mergeFromCodedBufferReader(CodedBufferReader input, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
inherited
mergeFromJson(String data, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from data, a JSON object, encoded as described by GeneratedMessage.writeToJson.
inherited
mergeFromJsonMap(Map<String, dynamic> json, [ExtensionRegistry extensionRegistry = ExtensionRegistry.EMPTY]) → void
Merges field values from a JSON object represented as a Dart map.
inherited
mergeFromMessage(GeneratedMessage other) → void
Merges the contents of the other into this message.
inherited
mergeFromProto3Json(Object? json, {TypeRegistry typeRegistry = const TypeRegistry.empty(), bool ignoreUnknownFields = false, bool supportNamesWithUnderscores = true, bool permissiveEnums = false}) → void
Merges field values from json, a JSON object using proto3 encoding.
inherited
mergeUnknownFields(UnknownFieldSet unknownFieldSet) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setExtension(Extension extension, Object value) → void
Sets the value of a non-repeated extension field to value.
inherited
setField(int tagNumber, Object value) → void
Sets the value of a field by its tagNumber.
inherited
toBuilder() → GeneratedMessage
Creates a writable, shallow copy of this message.
inherited
toDebugString() String
Returns a String representation of this message.
inherited
toProto3Json({TypeRegistry typeRegistry = const TypeRegistry.empty()}) Object?
Returns an Object representing Proto3 JSON serialization of this.
inherited
toString() String
Returns a String representation of this message.
inherited
writeToBuffer() Uint8List
inherited
writeToCodedBufferWriter(CodedBufferWriter output) → void
inherited
writeToJson() String
Returns a JSON string that encodes this message.
inherited
writeToJsonMap() Map<String, dynamic>
Returns the JSON encoding of this message as a Dart Map.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create() OrderedItem
createRepeated() → PbList<OrderedItem>
getDefault() OrderedItem