PaymentsDatacapServiceBase class abstract

Annotations
  • @GrpcServiceName.new('payments.v1.PaymentsDatacapService')

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
adjustTipAmount(ServiceCall call, DatacapAdjustTipRequest request) Future<DatacapResponse>
adjustTipAmount_Pre(ServiceCall call, Future<DatacapAdjustTipRequest> request) Future<DatacapResponse>
applyPreAuth(ServiceCall call, DatacapApplyPreAuthRequest request) Future<DatacapResponse>
applyPreAuth_Pre(ServiceCall call, Future<DatacapApplyPreAuthRequest> request) Future<DatacapResponse>
auditTransactions(ServiceCall call, AuditTransactionsRequest request) Future<DatacapResponse>
auditTransactions_Pre(ServiceCall call, Future<AuditTransactionsRequest> request) Future<DatacapResponse>
captureBatchAmounts(ServiceCall call, DatacapBatchAmountRequest request) Future<DatacapResponse>
captureBatchAmounts_Pre(ServiceCall call, Future<DatacapBatchAmountRequest> request) Future<DatacapResponse>
creditSale(ServiceCall call, DatacapCreditSaleRequest request) Future<DatacapResponse>
creditSale_Pre(ServiceCall call, Future<DatacapCreditSaleRequest> request) Future<DatacapResponse>
getTransactionData(ServiceCall call, DatacapGetTransactionDataRequest request) Future<DatacapResponse>
getTransactionData_Pre(ServiceCall call, Future<DatacapGetTransactionDataRequest> request) Future<DatacapResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
preAuthorization(ServiceCall call, DatacapPreAuthRequest request) Future<DatacapResponse>
preAuthorization_Pre(ServiceCall call, Future<DatacapPreAuthRequest> request) Future<DatacapResponse>
refundSale(ServiceCall call, DatacapRefundSaleRequest request) Future<DatacapResponse>
refundSale_Pre(ServiceCall call, Future<DatacapRefundSaleRequest> request) Future<DatacapResponse>
remoteCreditSale(ServiceCall call, DatacapRemoteCredSaleReq request) Future<DatacapResponse>
remoteCreditSale_Pre(ServiceCall call, Future<DatacapRemoteCredSaleReq> request) Future<DatacapResponse>
remotePreAuth(ServiceCall call, DatacapRemotePreAuthReq request) Future<DatacapResponse>
remotePreAuth_Pre(ServiceCall call, Future<DatacapRemotePreAuthReq> request) Future<DatacapResponse>
toString() String
A string representation of this object.
inherited
voidSale(ServiceCall call, DatacapVoidSaleRequest request) Future<DatacapResponse>
voidSale_Pre(ServiceCall call, Future<DatacapVoidSaleRequest> request) Future<DatacapResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited