PaymentsTgateServiceClient class

Annotations
  • @GrpcServiceName.new('payments.v1.PaymentsTgateService')

Constructors

PaymentsTgateServiceClient(ClientChannel channel, {CallOptions? options, Iterable<ClientInterceptor>? interceptors})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$createCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ClientCall<Q, R>
inherited
$createStreamingCall<Q, R>(ClientMethod<Q, R> method, Stream<Q> requests, {CallOptions? options}) → ResponseStream<R>
inherited
$createUnaryCall<Q, R>(ClientMethod<Q, R> method, Q request, {CallOptions? options}) → ResponseFuture<R>
inherited
adjustTip(TgateRequest request, {CallOptions? options}) → ResponseFuture<TgateResponse>
batchTransactions(TgateRequest request, {CallOptions? options}) → ResponseFuture<BatchResponse>
creditSale(TgateRequest request, {CallOptions? options}) → ResponseFuture<TgateResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refundAmount(TgateRequest request, {CallOptions? options}) → ResponseFuture<TgateResponse>
toString() String
A string representation of this object.
inherited
voidSale(TgateRequest request, {CallOptions? options}) → ResponseFuture<TgateResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited