ReportsProviderServiceBase class abstract

Annotations
  • @GrpcServiceName.new('reports.v1.ReportsProviderService')

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
getBrigadeInternalReports(ServiceCall call, GetBrigadeInternalReportsRequest request) Future<GetBrigadeInternalReportsResponse>
getBrigadeInternalReports_Pre(ServiceCall call, Future<GetBrigadeInternalReportsRequest> request) Future<GetBrigadeInternalReportsResponse>
getGeneralAvailabilityReports(ServiceCall call, GetGeneralAvailabilityReportsRequest request) Future<GetGeneralAvailabilityReportsResponse>
getGeneralAvailabilityReports_Pre(ServiceCall call, Future<GetGeneralAvailabilityReportsRequest> request) Future<GetGeneralAvailabilityReportsResponse>
getReport(ServiceCall call, GetReportRequest request) Future<GetReportResponse>
getReport_Pre(ServiceCall call, Future<GetReportRequest> request) Future<GetReportResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited