- Annotations
-
- @GrpcServiceName.new('labor.v1.EmployeesService')
Properties
-
$name
→ String
-
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
$addMethod(ServiceMethod method)
→ void
-
inherited
-
$lookupMethod(String name)
→ ServiceMethod?
-
inherited
-
$onMetadata(ServiceCall context)
→ void
-
Client metadata handler.
inherited
-
createEmployee(ServiceCall call, CreateEmployeeRequest request)
→ Future<CreateEmployeeResponse>
-
-
createEmployee_Pre(ServiceCall call, Future<CreateEmployeeRequest> request)
→ Future<CreateEmployeeResponse>
-
-
deleteEmployee(ServiceCall call, DeleteEmployeeRequest request)
→ Future<DeleteEmployeeResponse>
-
-
deleteEmployee_Pre(ServiceCall call, Future<DeleteEmployeeRequest> request)
→ Future<DeleteEmployeeResponse>
-
-
getAllEmployees(ServiceCall call, GetAllEmployeesRequest request)
→ Future<GetAllEmployeesResponse>
-
-
getAllEmployees_Pre(ServiceCall call, Future<GetAllEmployeesRequest> request)
→ Future<GetAllEmployeesResponse>
-
-
getEmployee(ServiceCall call, GetEmployeeRequest request)
→ Future<GetEmployeeResponse>
-
-
getEmployee_Pre(ServiceCall call, Future<GetEmployeeRequest> request)
→ Future<GetEmployeeResponse>
-
-
getEmployeeAvatar(ServiceCall call, GetEmployeeAvatarRequest request)
→ Future<GetEmployeeAvatarResponse>
-
-
getEmployeeAvatar_Pre(ServiceCall call, Future<GetEmployeeAvatarRequest> request)
→ Future<GetEmployeeAvatarResponse>
-
-
getEmployeeWithPin(ServiceCall call, GetEmployeeWithPinRequest request)
→ Future<GetEmployeeWithPinResponse>
-
-
getEmployeeWithPin_Pre(ServiceCall call, Future<GetEmployeeWithPinRequest> request)
→ Future<GetEmployeeWithPinResponse>
-
-
grantWebsiteAccess(ServiceCall call, GrantWebsiteAccessRequest request)
→ Future<GrantWebsiteAccessResponse>
-
-
grantWebsiteAccess_Pre(ServiceCall call, Future<GrantWebsiteAccessRequest> request)
→ Future<GrantWebsiteAccessResponse>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
revokeWebsiteAccess(ServiceCall call, RevokeWebsiteAccessRequest request)
→ Future<RevokeWebsiteAccessResponse>
-
-
revokeWebsiteAccess_Pre(ServiceCall call, Future<RevokeWebsiteAccessRequest> request)
→ Future<RevokeWebsiteAccessResponse>
-
-
sendEmployeePasswordReset(ServiceCall call, SendEmployeePasswordResetRequest request)
→ Future<SendEmployeePasswordResetResponse>
-
-
sendEmployeePasswordReset_Pre(ServiceCall call, Future<SendEmployeePasswordResetRequest> request)
→ Future<SendEmployeePasswordResetResponse>
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
updateEmployee(ServiceCall call, UpdateEmployeeRequest request)
→ Future<UpdateEmployeeResponse>
-
-
updateEmployee_Pre(ServiceCall call, Future<UpdateEmployeeRequest> request)
→ Future<UpdateEmployeeResponse>
-
-
updateEmployeeAvatar(ServiceCall call, UpdateEmployeeAvatarRequest request)
→ Future<UpdateEmployeeAvatarResponse>
-
-
updateEmployeeAvatar_Pre(ServiceCall call, Future<UpdateEmployeeAvatarRequest> request)
→ Future<UpdateEmployeeAvatarResponse>
-